==> flutter_simple_template_bloc-0.0.3.tar.gz: lib/blocs/generic_base_bloc.dart <==
import 'dart:async';

import 'package:flutter_bloc/flutter_bloc.dart';

abstract class GenericBaseBloc<Event, State> extends Bloc<Event, State> {
  GenericBaseBloc(super.initialState) {
    initData();
    addObserver();
  }

  final List<StreamSubscription> _subscriptions = [];

  // call when init bloc
  // ex: create controller or listener
  void initData() async {}

  // close or cancel stream,controller,listener
  void closeData() {}

  // handle Error
  void handleError(dynamic error) async {}

  // show loading
  void showLoading() {}

  // hide loading
  void dismissLoading() {}

  void showSnackBar({String? title, required String message}) {}

  void showPopUpDialog(
    String? title,
    String content,
    String? description,
    String? cancelTitle,
    String? buttonTitle, // 'ok'
    bool? barrierDismissible, // false
  ) async {}

  // Handle app lifcycle
  // WidgetsBinding.instance.addObserver(AppLifecycleObserver(this));
  // WidgetsBinding.instance.addObserver(AppLifecycleObserver(appPausedEvent,appResumedEvent));
  void addObserver() async {}

  // remove listen observer
  // WidgetsBinding.instance.removeObserver(AppLifecycleObserver(this));
  // WidgetsBinding.instance.removeObserver(AppLifecycleObserver(appPausedEvent,appResumedEvent));
  void removeObserver() {}

  @override
  Future<void> close() {
    closeData();
    removeObserver();
    int i = 0;
    while (i < _subscriptions.length) {
      _subscriptions[i].cancel();
      i++;
    }
    return super.close();
  }
}

==> flutter_simple_template_bloc-0.0.8.tar.gz: lib/blocs/generic_base_bloc.dart <==
import 'dart:async';

import 'package:flutter_bloc/flutter_bloc.dart';

abstract class GenericBaseBloc<Event, State> extends Bloc<Event, State> {
  GenericBaseBloc(super.initialState) {
    initData();
    addObserver();
  }

  final List<StreamSubscription> _subscriptions = [];

  // call when init bloc
  // ex: create controller or listener
  void initData() async {}

  // close or cancel stream,controller,listener
  void closeData() {}

  // handle Error
  void handleError(dynamic error) async {}

  // show loading
  void showLoading() {}

  // hide loading
  void dismissLoading() {}

  void showSnackBar({String? title, required String message}) {}

  void showPopUpDialog({
    String? title,
    required String content,
    String? description,
    String? cancelTitle,
    String? buttonTitle, // 'ok'
    bool? barrierDismissible, // false
  }) async {}

  // Handle app lifcycle
  // WidgetsBinding.instance.addObserver(AppLifecycleObserver(this));
  // WidgetsBinding.instance.addObserver(AppLifecycleObserver(appPausedEvent,appResumedEvent));
  void addObserver() async {}

  // remove listen observer
  // WidgetsBinding.instance.removeObserver(AppLifecycleObserver(this));
  // WidgetsBinding.instance.removeObserver(AppLifecycleObserver(appPausedEvent,appResumedEvent));
  void removeObserver() {}

  @override
  Future<void> close() {
    closeData();
    removeObserver();
    int i = 0;
    while (i < _subscriptions.length) {
      _subscriptions[i].cancel();
      i++;
    }
    return super.close();
  }
}
